pub enum PinStrategy {
Core,
Logical,
Spread,
}Expand description
Pinning strategy for a list of thread handles.
Variants
Core
Pin each thread to a unique physical core (one thread per core, preferring physical core 0, 1, 2, …).
Logical
Pin each thread to a unique logical processor (SMT thread).
Spread
Spread threads across cores to maximize per-thread cache, mapping each thread to a different L3 / NUMA region when possible.